pub struct CommitRequest {
pub mode: Option<String>,
pub mutations: Option<Vec<Mutation>>,
pub transaction: Option<Vec<u8>>,
}Expand description
The request for Datastore.Commit.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- commit projects (request)
Fields
mode: Option<String>The type of commit to perform. Defaults to TRANSACTIONAL.
mutations: Option<Vec<Mutation>>The mutations to perform. When mode is TRANSACTIONAL, mutations affecting a single entity are applied in order. The following sequences of mutations affecting a single entity are not permitted in a single Commit request: - insert followed by insert - update followed by insert - upsert followed by insert - delete followed by update When mode is NON_TRANSACTIONAL, no two mutations may affect a single entity.
transaction: Option<Vec<u8>>The identifier of the transaction associated with the commit. A transaction identifier is returned by a call to Datastore.BeginTransaction.