pub struct ProjectMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on project resources.
It is not used directly, but through the Datastore hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_datastore1_beta3 as datastore1_beta3;
use datastore1_beta3::{Datastore, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = Datastore::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `allocate_ids(...)`, `begin_transaction(...)`, `commit(...)`, `lookup(...)`, `reserve_ids(...)`, `rollback(...)`, `run_aggregation_query(...)` and `run_query(...)`
// to build up your call.
let rb = hub.projects();Implementations
Sourceimpl<'a, C> ProjectMethods<'a, C>
impl<'a, C> ProjectMethods<'a, C>
Sourcepub fn allocate_ids(
&self,
request: AllocateIdsRequest,
project_id: &str,
) -> ProjectAllocateIdCall<'a, C>
pub fn allocate_ids( &self, request: AllocateIdsRequest, project_id: &str, ) -> ProjectAllocateIdCall<'a, C>
Create a builder to help you perform the following task:
Allocates IDs for the given keys, which is useful for referencing an entity before it is inserted.
Arguments
request- No description provided.projectId- Required. The ID of the project against which to make the request.
Sourcepub fn begin_transaction(
&self,
request: BeginTransactionRequest,
project_id: &str,
) -> ProjectBeginTransactionCall<'a, C>
pub fn begin_transaction( &self, request: BeginTransactionRequest, project_id: &str, ) -> ProjectBeginTransactionCall<'a, C>
Create a builder to help you perform the following task:
Begins a new transaction.
Arguments
request- No description provided.projectId- Required. The ID of the project against which to make the request.
Sourcepub fn commit(
&self,
request: CommitRequest,
project_id: &str,
) -> ProjectCommitCall<'a, C>
pub fn commit( &self, request: CommitRequest, project_id: &str, ) -> ProjectCommitCall<'a, C>
Create a builder to help you perform the following task:
Commits a transaction, optionally creating, deleting or modifying some entities.
Arguments
request- No description provided.projectId- Required. The ID of the project against which to make the request.
Sourcepub fn lookup(
&self,
request: LookupRequest,
project_id: &str,
) -> ProjectLookupCall<'a, C>
pub fn lookup( &self, request: LookupRequest, project_id: &str, ) -> ProjectLookupCall<'a, C>
Create a builder to help you perform the following task:
Looks up entities by key.
Arguments
request- No description provided.projectId- Required. The ID of the project against which to make the request.
Sourcepub fn reserve_ids(
&self,
request: ReserveIdsRequest,
project_id: &str,
) -> ProjectReserveIdCall<'a, C>
pub fn reserve_ids( &self, request: ReserveIdsRequest, project_id: &str, ) -> ProjectReserveIdCall<'a, C>
Create a builder to help you perform the following task:
Prevents the supplied keys’ IDs from being auto-allocated by Cloud Datastore.
Arguments
request- No description provided.projectId- Required. The ID of the project against which to make the request.
Sourcepub fn rollback(
&self,
request: RollbackRequest,
project_id: &str,
) -> ProjectRollbackCall<'a, C>
pub fn rollback( &self, request: RollbackRequest, project_id: &str, ) -> ProjectRollbackCall<'a, C>
Create a builder to help you perform the following task:
Rolls back a transaction.
Arguments
request- No description provided.projectId- Required. The ID of the project against which to make the request.
Sourcepub fn run_aggregation_query(
&self,
request: RunAggregationQueryRequest,
project_id: &str,
) -> ProjectRunAggregationQueryCall<'a, C>
pub fn run_aggregation_query( &self, request: RunAggregationQueryRequest, project_id: &str, ) -> ProjectRunAggregationQueryCall<'a, C>
Create a builder to help you perform the following task:
Runs an aggregation query.
Arguments
request- No description provided.projectId- Required. The ID of the project against which to make the request.
Sourcepub fn run_query(
&self,
request: RunQueryRequest,
project_id: &str,
) -> ProjectRunQueryCall<'a, C>
pub fn run_query( &self, request: RunQueryRequest, project_id: &str, ) -> ProjectRunQueryCall<'a, C>
Create a builder to help you perform the following task:
Queries for entities.
Arguments
request- No description provided.projectId- Required. The ID of the project against which to make the request.